Index: src/work/marci/leda/bipartite_matching_leda.cc
===================================================================
--- src/work/marci/leda/bipartite_matching_leda.cc	(revision 769)
+++ src/work/marci/leda/bipartite_matching_leda.cc	(revision 921)
@@ -14,10 +14,10 @@
 //#include <smart_graph.h>
 //#include <dimacs.h>
-#include <hugo/time_measure.h>
+#include <lemon/time_measure.h>
 #include <for_each_macros.h>
-#include <hugo/graph_wrapper.h>
+#include <lemon/graph_wrapper.h>
 #include <bipartite_graph_wrapper.h>
-#include <hugo/maps.h>
-#include <hugo/max_flow.h>
+#include <lemon/maps.h>
+#include <lemon/max_flow.h>
 
 /**
@@ -43,5 +43,5 @@
 }
 
-using namespace hugo;
+using namespace lemon;
 
 int main() {
Index: src/work/marci/leda/bipartite_matching_leda_gen.cc
===================================================================
--- src/work/marci/leda/bipartite_matching_leda_gen.cc	(revision 769)
+++ src/work/marci/leda/bipartite_matching_leda_gen.cc	(revision 921)
@@ -14,10 +14,10 @@
 //#include <smart_graph.h>
 //#include <dimacs.h>
-#include <hugo/time_measure.h>
+#include <lemon/time_measure.h>
 #include <for_each_macros.h>
-#include <hugo/graph_wrapper.h>
+#include <lemon/graph_wrapper.h>
 #include <bipartite_graph_wrapper.h>
-#include <hugo/maps.h>
-#include <hugo/max_flow.h>
+#include <lemon/maps.h>
+#include <lemon/max_flow.h>
 #include <augmenting_flow.h>
 
@@ -44,5 +44,5 @@
 }
 
-using namespace hugo;
+using namespace lemon;
 
 int main() {
@@ -111,5 +111,5 @@
     max_flow_test(stgw, stgw.S_NODE, stgw.T_NODE, const1map, flow/*, true*/);
   max_flow_test.run();
-  std::cout << "HUGO max matching algorithm based on preflow." << std::endl 
+  std::cout << "LEMON max matching algorithm based on preflow." << std::endl 
 	    << "Size of matching: " 
 	    << max_flow_test.flowValue() << std::endl;
@@ -130,5 +130,5 @@
     max_flow_test_1(stgw, stgw.S_NODE, stgw.T_NODE, const1map, flow/*, true*/);
   while (max_flow_test_1.augmentOnBlockingFlow<MutableGraph>()) { }
-  std::cout << "HUGO max matching algorithm based on blocking flow augmentation." 
+  std::cout << "LEMON max matching algorithm based on blocking flow augmentation." 
 	    << std::endl << "Matching size: " 
 	    << max_flow_test_1.flowValue() << std::endl;
Index: src/work/marci/leda/max_bipartite_matching_demo.cc
===================================================================
--- src/work/marci/leda/max_bipartite_matching_demo.cc	(revision 771)
+++ src/work/marci/leda/max_bipartite_matching_demo.cc	(revision 921)
@@ -37,5 +37,5 @@
 }
 
-using namespace hugo;
+using namespace lemon;
 
 using std::cout; 

Index: src/work/marci/leda/bipartite_matching_comparison.cc
===================================================================
--- src/work/marci/leda/bipartite_matching_comparison.cc	(revision 771)
+++ src/work/marci/leda/bipartite_matching_comparison.cc	(revision 921)
@@ -14,10 +14,10 @@
 //#include <smart_graph.h>
 //#include <dimacs.h>
-#include <hugo/time_measure.h>
+#include <lemon/time_measure.h>
 #include <for_each_macros.h>
-#include <hugo/graph_wrapper.h>
+#include <lemon/graph_wrapper.h>
 #include <bipartite_graph_wrapper.h>
-#include <hugo/maps.h>
-#include <hugo/max_flow.h>
+#include <lemon/maps.h>
+#include <lemon/max_flow.h>
 
 using std::cin;
@@ -25,5 +25,5 @@
 using std::endl;
 
-using namespace hugo;
+using namespace lemon;
 
 int main() {
@@ -92,5 +92,5 @@
     max_flow_test(stgw, stgw.S_NODE, stgw.T_NODE, const1map, flow/*, true*/);
   max_flow_test.run();
-  cout << "HUGO max matching algorithm based on preflow." << endl 
+  cout << "LEMON max matching algorithm based on preflow." << endl 
 	    << "Size of matching: " 
 	    << max_flow_test.flowValue() << endl;
@@ -108,5 +108,5 @@
 //   typedef SageGraph MutableGraph;
 //   while (max_flow_test.augmentOnBlockingFlow<MutableGraph>()) { }
 //   cout << "HUGO max matching algorithm based on blocking flow augmentation." 
 // 	    << endl << "Matching size: " 
 // 	    << max_flow_test.flowValue() << endl;
@@ -142,5 +142,5 @@
     max_flow_test(hg, s, t, cm, flow);
   max_flow_test.run();
-  cout << "HUGO max matching algorithm on SageGraph by copying the graph, based on preflow." 
+  cout << "LEMON max matching algorithm on SageGraph by copying the graph, based on preflow." 
 	    << endl 
 	    << "Size of matching: " 
@@ -108,5 +108,5 @@
 //   typedef SageGraph MutableGraph;
 //   while (max_flow_test.augmentOnBlockingFlow<MutableGraph>()) { }
-//   cout << "HUGO max matching algorithm based on blocking flow augmentation." 
+//   cout << "LEMON max matching algorithm based on blocking flow augmentation." 
 // 	    << endl << "Matching size: " 
 // 	    << max_flow_test.flowValue() << endl;
Index: src/work/marci/leda/leda_graph_wrapper.h
===================================================================
--- src/work/marci/leda/leda_graph_wrapper.h	(revision 650)
+++ src/work/marci/leda/leda_graph_wrapper.h	(revision 921)
@@ -1,5 +1,5 @@
 // -*- c++ -*-
-#ifndef HUGO_LEDA_GRAPH_WRAPPER_H
-#define HUGO_LEDA_GRAPH_WRAPPER_H
+#ifndef LEMON_LEDA_GRAPH_WRAPPER_H
+#define LEMON_LEDA_GRAPH_WRAPPER_H
 
 #include <LEDA/graph.h>
@@ -15,13 +15,13 @@
 //#endif
 
-#include <hugo/invalid.h>
-
-namespace hugo {
-
-  /// \brief A graph wrapper structure for wrapping LEDA graphs in HUGO.
+#include <lemon/invalid.h>
+
+namespace lemon {
+
+  /// \brief A graph wrapper structure for wrapping LEDA graphs in LEMON.
   ///
   /// This graph wrapper class wraps LEDA graphs and LEDA parametrized graphs
   /// to satisfy HUGO graph concepts.
   /// Then the generic HUGOlib algorithms and wrappers can be used 
   /// with LEDA graphs. 
   /// \ingroup gwrapper
@@ -299,5 +299,5 @@
 
     /// This class is to wrap existing 
     /// LEDA node-maps to HUGO ones.
     template<typename T> class NodeMapWrapper
     {
@@ -321,5 +321,5 @@
 
     /// This class is to wrap existing 
     /// LEDA edge-maps to HUGO ones.
     template<typename T> class EdgeMapWrapper
     {
@@ -380,5 +380,5 @@
   };
 
-} //namespace hugo
-
-#endif // HUGO_LEDA_GRAPH_WRAPPER_H
+} //namespace lemon
+
+#endif // LEMON_LEDA_GRAPH_WRAPPER_H
@@ -15,13 +15,13 @@
   ///
   /// This graph wrapper class wraps LEDA graphs and LEDA parametrized graphs
-  /// to satisfy HUGO graph concepts.
-  /// Then the generic HUGOlib algorithms and wrappers can be used 
+  /// to satisfy LEMON graph concepts.
+  /// Then the generic LEMON algorithms and wrappers can be used 
   /// with LEDA graphs. 
   /// \ingroup gwrapper
@@ -299,5 +299,5 @@
 
     /// This class is to wrap existing 
-    /// LEDA node-maps to HUGO ones.
+    /// LEDA node-maps to LEMON ones.
     template<typename T> class NodeMapWrapper
     {
@@ -321,5 +321,5 @@
 
     /// This class is to wrap existing 
-    /// LEDA edge-maps to HUGO ones.
+    /// LEDA edge-maps to LEMON ones.
     template<typename T> class EdgeMapWrapper
     {